@@ -11,7 +11,7 @@ use URPM::Resolve;
 use URPM::Signature;
 
 our @ISA = qw(DynaLoader);
-our $VERSION = '5.15.14';
+our $VERSION = '5.19.1';
 
 URPM->bootstrap($VERSION);
 
@@ -874,6 +874,7 @@ Recognized options are:
     callback_open   => sub { ... }
     callback_trans  => sub { ... }
     callback_uninst => sub { ... }
+    callback_verify => sub { ... }
     delta => used for progress callbacks (trans, uninst, inst)
     excludedocs => 0 / 1
     force => 0 / 1
@@ -966,9 +967,11 @@ Destroys macros.
 
 =over
 
-=item specbuild($specfile, ...)
+=item specbuild($mode, $specfile, [ defines => [ '_topdir /tmp/XYZ', ... ] ])
 
 Build a package from the spec file pointed by the file path. It's possible to define extra macros.
+B<$mode> is one of 'ba', 'bb' or 'bs'.
+B<defines> enables to define some value (like rpmbuild --define '_topdir /tmp/').
 
 =item setVerbosity($level)
 
